/**********************************************************************
 *
 * search.cpp -- abstract search class for mg
 * Copyright (C) 1999  The New Zealand Digital Library Project
 *
 * A component of the Greenstone digital library software
 * from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: search.cpp 1324 2000-08-02 00:58:29Z kjm18 $
 *
 *********************************************************************/

/*
   $Log$
   Revision 1.1  2000/08/02 00:58:29  kjm18
   mgpp incorporated. the old mgsearchclass and queryfilterclass are changed.
   Have a base searchclass, from which mgsearchclass and mgppsearchclass inherit.
   Have a base queryfilterclass, from which mgqueryfilterclass and
   mgppqueryfilterclass inherit. librarymain in recpt should choose the appropriate
   type (mg vs mgpp) for each collection.

   Revision 1.22  1999/09/24 02:41:21  rjmcnab
   change to use has_unicode_letdig in text_t

   Revision 1.21  1999/09/21 21:41:41  sjboddie
   fixed an error in what I committed last

   Revision 1.20  1999/09/21 11:59:26  sjboddie
   added Maxdocs queryfilter option (which may be -1 for 'all)

   Revision 1.19  1999/09/07 22:52:52  rjmcnab
   Seems to be an error in mg for retrieving documents using a paragraph
   based index for some cases. Just added a work around (loads the default
   index every time).

   Revision 1.18  1999/09/07 04:57:22  sjboddie
   added gpl notice

   Revision 1.17  1999/08/31 22:42:41  rjmcnab
   A couple of minor things.

   Revision 1.16  1999/08/25 04:51:06  sjboddie
   small change to allow for searching using boolean operators

   Revision 1.15  1999/07/16 08:35:03  rjmcnab
   Fixed a weird bug to do with a faulty case statement.

   Revision 1.14  1999/07/16 03:42:22  sjboddie
   changed isApprox

   Revision 1.13  1999/07/16 00:12:46  sjboddie
   removed all the old post-processing stuff

   Revision 1.12  1999/07/07 06:17:47  rjmcnab
   broke search_index into index+subcollection+language
   within mgsearch

   Revision 1.11  1999/07/05 21:06:43  rjmcnab
   Disabled quoted strings.

   Revision 1.10  1999/07/01 09:29:19  rjmcnab
   Changes for better reporting of number documents which match a query. Changes
   should still work as before with older versions of mg.

   Revision 1.9  1999/07/01 03:54:48  rjmcnab
   Added code to plug in the equivalent terms of each of the query terms.
   Also added a function to get a raw utf8 encoded mg document (for speeding
   up a phrase matching function)

   Revision 1.8  1999/06/30 04:04:12  rjmcnab
   made stemming functions available from mgsearch and made the stems
   for the query terms available in queryinfo

   Revision 1.7  1999/06/27 22:07:27  sjboddie
   got rid of all the old functions for dealing with dir indexes

   Revision 1.6  1999/06/09 00:41:32  sjboddie
   phrase searching now uses case-folding if it's turned on

   Revision 1.5  1999/02/21 22:31:35  rjmcnab

   Removed locateinfo.

   Revision 1.4  1999/02/03 01:13:27  sjboddie

   Got interface to handle subcollections and language subcollections -
   committed changes made to some of the collections

   Revision 1.3  1999/01/19 01:38:17  rjmcnab

   Made the source more portable.

   Revision 1.2  1999/01/12 01:51:02  rjmcnab

   Standard header.

   Revision 1.1  1999/01/08 09:02:16  rjmcnab

   Moved from src/library.

 */

#include "search.h"

////////////////////
// search class //
////////////////////

searchclass::searchclass ()
{
  cache = new querycache (RESULTCACHESIZE);
 
}

searchclass::~searchclass () 
{
  if (cache != NULL) 
    {
      delete cache;
      cache = NULL;
    }
}


void searchclass::setcollectdir (const text_t &thecollectdir)
{
  collectdir = thecollectdir;
}


